pub struct TorEventReceiver { /* private fields */ }Expand description
A receiver for TorEvents emitted by other users of this crate.
To use this type, first subscribe to some kinds of event by calling
TorEventReceiver::subscribe. Then, consume events using the implementation of
futures::stream::Stream.
Warning
Once interest in events has been signalled with subscribe, events must be continuously
read from the receiver in order to avoid excessive memory consumption.
Implementations
Sourceimpl TorEventReceiver
impl TorEventReceiver
Sourcepub fn subscribe(&mut self, kind: TorEventKind)
pub fn subscribe(&mut self, kind: TorEventKind)
Subscribe to a given kind of TorEvent.
After calling this function, TorEventReceiver::recv will emit events of that kind.
This function is idempotent (subscribing twice has the same effect as doing so once).
Sourcepub fn unsubscribe(&mut self, kind: TorEventKind)
pub fn unsubscribe(&mut self, kind: TorEventKind)
Unsubscribe from a given kind of TorEvent.
After calling this function, TorEventReceiver::recv will no longer emit events of that
kind.
This function is idempotent (unsubscribing twice has the same effect as doing so once).